﻿using System;
using System.Collections.Generic;
using System.Collections.ObjectModel;
using System.ComponentModel;
using System.Linq;
using System.Text;
using System.Threading.Tasks;

namespace Sample
{
    public class ViewModel : INotifyPropertyChanged
    {

        private ObservableCollection<MyDictionary> collection;
        private ObservableCollection<EnglishToOther> germanCollection;
        private ObservableCollection<EnglishToOther> frencheCollection;
        private ObservableCollection<EnglishToOther> spanisheCollection;

        public ObservableCollection<MyDictionary> Collection
        {
            get { return collection; }
            set
            {
                collection = value;
                OnPropertyChanged("Collection");
            }
        }

        public ObservableCollection<EnglishToOther> GermanCollection
        {
            get { return germanCollection; }
        }

        public ObservableCollection<EnglishToOther> FrencheCollection
        {
            get { return frencheCollection; }
        }

        public ObservableCollection<EnglishToOther> SpanisheCollection
        {
            get { return spanisheCollection; }
        }

        public ViewModel()
        {
            germanCollection = new ObservableCollection<EnglishToOther>
                {
                    new EnglishToOther() {English = "car", Other = "wagen"},
                    new EnglishToOther() {English = "store", Other = "geschaft"},
                    new EnglishToOther() {English = "man", Other = "mann"},
                    new EnglishToOther() {English = "women", Other = "frau"},
                };

            frencheCollection = new ObservableCollection<EnglishToOther>
                {
                    new EnglishToOther() {English = "car", Other = "voiture"},
                    new EnglishToOther() {English = "store", Other = "magasin"},
                    new EnglishToOther() {English = "table", Other = "table"},
                    new EnglishToOther() {English = "women", Other = "femme"},
                    new EnglishToOther() {English = "keyboard", Other = "clavier"},
                    new EnglishToOther() {English = "screen", Other = "ecran"},
                };

            spanisheCollection = new ObservableCollection<EnglishToOther>
                {
                    new EnglishToOther() {English = "car", Other = "coche"},
                    new EnglishToOther() {English = "store", Other = "tienda"},
                    new EnglishToOther() {English = "man", Other = "hombre"},
                    new EnglishToOther() {English = "book", Other = "libro"},
                    new EnglishToOther() {English = "screen", Other = "pa,talla"},
                };

            var result = GermanCollection.Concat(frencheCollection).Concat(spanisheCollection).Select(eng => eng.English).Distinct();
            collection = new ObservableCollection<MyDictionary>();
            foreach (var eng in result)
            {
                var dict = new MyDictionary();
                dict.English = eng;

                var g = GermanCollection.FirstOrDefault(ger => ger.English == eng);
                if (g == null)
                {
                    g = new EnglishToOther() {English = eng};
                    GermanCollection.Add(g);
                }
                dict.German = g;

                var f = FrencheCollection.FirstOrDefault(fre => fre.English == eng);
                if (f == null)
                {
                    f = new EnglishToOther() { English = eng };
                    FrencheCollection.Add(f);
                }
                dict.French = f;

                var s = SpanisheCollection.FirstOrDefault(spa => spa.English == eng);
                if (s == null)
                {
                    s = new EnglishToOther() { English = eng };
                    SpanisheCollection.Add(s);
                }
                dict.Spanish = s;

                collection.Add(dict);
            }
        }

        public event PropertyChangedEventHandler PropertyChanged;

        private void OnPropertyChanged(String prop)
        {
            if (PropertyChanged != null)
            {
                PropertyChanged(this, new PropertyChangedEventArgs(prop));
            }
        }
    }
}
